@@ -20,7 +20,6 @@ from osc_lib.command import command
 from osc_lib import exceptions as exc
 from osc_lib import utils
 from oslo_utils import strutils
-import six
 
 from senlinclient.common.i18n import _
 from senlinclient.common import utils as senlin_utils
@@ -86,7 +85,8 @@ class ListNode(command.Lister):
         senlin_client = self.app.client_manager.clustering
 
         columns = ['id', 'name', 'index', 'status', 'cluster_id',
-                   'physical_id', 'profile_name', 'created_at', 'updated_at']
+                   'physical_id', 'profile_name', 'created_at', 'updated_at',
+                   'tainted']
         queries = {
             'cluster_id': parsed_args.cluster,
             'sort': parsed_args.sort,
@@ -254,6 +254,14 @@ class UpdateNode(command.ShowOne):
                    "can clean metadata "),
             action='append'
         )
+        parser.add_argument(
+            '--tainted',
+            metavar='<boolean>',
+            help=_("Whether the node should be marked as tainted. "
+                   "If true, this node will be selected first for the next"
+                   "cluster scale-in operation.")
+
+        )
         parser.add_argument(
             'node',
             metavar='<node>',
@@ -278,6 +286,12 @@ class UpdateNode(command.ShowOne):
             'metadata': senlin_utils.format_parameters(parsed_args.metadata),
         }
 
+        if parsed_args.tainted is not None:
+            attrs['tainted'] = strutils.bool_from_string(
+                parsed_args.tainted,
+                strict=True,
+            )
+
         senlin_client.update_node(node.id, **attrs)
         return _show_node(senlin_client, node.id)
 
@@ -316,6 +330,7 @@ class DeleteNode(command.Command):
                 sys.stdout.write(
                     _("Are you sure you want to delete this node(s)"
                       " [y/N]?"))
+                sys.stdout.flush()
                 prompt_response = sys.stdin.readline().lower()
                 if not prompt_response.startswith('y'):
                     return
@@ -329,11 +344,11 @@ class DeleteNode(command.Command):
         result = {}
         for nid in parsed_args.node:
             try:
-                node = senlin_client.delete_node(
+                node_delete_action = senlin_client.delete_node(
                     nid, False, parsed_args.force_delete)
-                result[nid] = ('OK', node.location.split('/')[-1])
+                result[nid] = ('OK', node_delete_action['id'])
             except Exception as ex:
-                result[nid] = ('ERROR', six.text_type(ex))
+                result[nid] = ('ERROR', str(ex))
 
         for rid, res in result.items():
             senlin_utils.print_action_result(rid, res)
